//=============================================================================
// Copyright (c) 2016-present Allan CORNET (Nelson)
//=============================================================================
// This file is part of the Nelson.
//=============================================================================
// LICENCE_BLOCK_BEGIN
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// Alternatively, you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this program. If not, see <http://www.gnu.org/licenses/>.
// LICENCE_BLOCK_END
//=============================================================================
#include "ErrorEmitter.h"
#include "DebugStack.hpp"
#include "Interface.hpp"
//=============================================================================
static Nelson::Evaluator* evaluatorError = nullptr;
//=============================================================================
namespace Nelson {
//=============================================================================
void
setErrorEvaluator(Evaluator* eval)
{
    evaluatorError = eval;
}
//=============================================================================
void
throwException(const Exception& e)
{
    throw e;
}
//=============================================================================
} // namespace Nelson
//=============================================================================
void
NelsonErrorEmitter(const wchar_t* msg, const wchar_t* id, bool asCaller)
{
    std::wstring message(msg);
    if (!message.empty()) {
        if (evaluatorError != nullptr) {
            std::wstring identifier(id);
            Nelson::stackTrace trace;
            DebugStack(evaluatorError->callstack, asCaller ? 1 : 0, trace);
            Nelson::Exception exception(message, trace, identifier);
            Nelson::throwException(exception);
        }
    }
}
//=============================================================================
